Status

Enum Status 

#[repr(C)]
pub enum Status {
Show 104 variants Ok = 0, BadArg = 1, Invalid = 2, Unsupported = 3, Eof = 4, Io = 5, Oom = 6, A1lxEssential = 7, A1opNoEssential = 8, AlacBadMagicCookieSize = 9, AlacFlagsNonzero = 10, Av1cMissing = 11, BitReaderError = 12, BoxBadSize = 13, BoxBadWideSize = 14, CheckParserStateErr = 15, ColrBadQuantity = 16, ColrBadSize = 17, ColrBadType = 18, ColrReservedNonzero = 19, ConstructionMethod = 20, CttsBadSize = 21, CttsBadVersion = 22, DflaBadMetadataBlockSize = 23, DflaFlagsNonzero = 24, DflaMissingMetadata = 25, DflaStreamInfoBadSize = 26, DflaStreamInfoNotFirst = 27, DopsChannelMappingWriteErr = 28, DopsOpusHeadWriteErr = 29, ElstBadVersion = 30, EsdsBadAudioSampleEntry = 31, EsdsBadDescriptor = 32, EsdsDecSpecificIntoTagQuantity = 33, FtypBadSize = 34, FtypNotFirst = 35, HdlrNameNoNul = 36, HdlrNameNotUtf8 = 37, HdlrNotFirst = 38, HdlrPredefinedNonzero = 39, HdlrReservedNonzero = 40, HdlrTypeNotPict = 41, HdlrUnsupportedVersion = 42, HdrlBadQuantity = 43, IdatBadQuantity = 44, IdatMissing = 45, IinfBadChild = 46, IinfBadQuantity = 47, IlocBadConstructionMethod = 48, IlocBadExtent = 49, IlocBadExtentCount = 50, IlocBadFieldSize = 51, IlocBadQuantity = 52, IlocBadSize = 53, IlocDuplicateItemId = 54, IlocNotFound = 55, IlocOffsetOverflow = 56, ImageItemType = 57, InfeFlagsNonzero = 58, InvalidUtf8 = 59, IpcoIndexOverflow = 60, IpmaBadIndex = 61, IpmaBadItemOrder = 62, IpmaBadQuantity = 63, IpmaBadVersion = 64, IpmaDuplicateItemId = 65, IpmaFlagsNonzero = 66, IpmaIndexZeroNoEssential = 67, IpmaTooBig = 68, IpmaTooSmall = 69, IprpBadChild = 70, IprpBadQuantity = 71, IprpConflict = 72, IrefBadQuantity = 73, IrefRecursion = 74, IspeMissing = 75, ItemTypeMissing = 76, LselNoEssential = 77, MdhdBadTimescale = 78, MdhdBadVersion = 79, MehdBadVersion = 80, MetaBadQuantity = 81, MissingAvifOrAvisBrand = 82, MissingMif1Brand = 83, MoovBadQuantity = 84, MoovMissing = 85, MultipleAlpha = 86, MvhdBadTimescale = 87, MvhdBadVersion = 88, NoImage = 89, PitmBadQuantity = 90, PitmMissing = 91, PitmNotFound = 92, PixiBadChannelCount = 93, PixiMissing = 94, PsshSizeOverflow = 95, ReadBufErr = 96, SchiQuantity = 97, StsdBadAudioSampleEntry = 98, StsdBadVideoSampleEntry = 99, TkhdBadVersion = 100, TxformBeforeIspe = 101, TxformNoEssential = 102, TxformOrder = 103,
}
The return value to the C API Any detail that needs to be communicated to the caller must be encoded here since the Error type’s associated data is part of the FFI.

Variants



Ok = 0



BadArg = 1



Invalid = 2



Unsupported = 3



Eof = 4



Io = 5



Oom = 6



A1lxEssential = 7



A1opNoEssential = 8



AlacBadMagicCookieSize = 9



AlacFlagsNonzero = 10



Av1cMissing = 11



BitReaderError = 12



BoxBadSize = 13



BoxBadWideSize = 14



CheckParserStateErr = 15



ColrBadQuantity = 16



ColrBadSize = 17



ColrBadType = 18



ColrReservedNonzero = 19



ConstructionMethod = 20



CttsBadSize = 21



CttsBadVersion = 22



DflaBadMetadataBlockSize = 23



DflaFlagsNonzero = 24



DflaMissingMetadata = 25



DflaStreamInfoBadSize = 26



DflaStreamInfoNotFirst = 27



DopsChannelMappingWriteErr = 28



DopsOpusHeadWriteErr = 29



ElstBadVersion = 30



EsdsBadAudioSampleEntry = 31



EsdsBadDescriptor = 32



EsdsDecSpecificIntoTagQuantity = 33



FtypBadSize = 34



FtypNotFirst = 35



HdlrNameNoNul = 36



HdlrNameNotUtf8 = 37



HdlrNotFirst = 38



HdlrPredefinedNonzero = 39



HdlrReservedNonzero = 40



HdlrTypeNotPict = 41



HdlrUnsupportedVersion = 42



HdrlBadQuantity = 43



IdatBadQuantity = 44



IdatMissing = 45



IinfBadChild = 46



IinfBadQuantity = 47



IlocBadConstructionMethod = 48



IlocBadExtent = 49



IlocBadExtentCount = 50



IlocBadFieldSize = 51



IlocBadQuantity = 52



IlocBadSize = 53



IlocDuplicateItemId = 54



IlocNotFound = 55



IlocOffsetOverflow = 56



ImageItemType = 57



InfeFlagsNonzero = 58



InvalidUtf8 = 59



IpcoIndexOverflow = 60



IpmaBadIndex = 61



IpmaBadItemOrder = 62



IpmaBadQuantity = 63



IpmaBadVersion = 64



IpmaDuplicateItemId = 65



IpmaFlagsNonzero = 66



IpmaIndexZeroNoEssential = 67



IpmaTooBig = 68



IpmaTooSmall = 69



IprpBadChild = 70



IprpBadQuantity = 71



IprpConflict = 72



IrefBadQuantity = 73



IrefRecursion = 74



IspeMissing = 75



ItemTypeMissing = 76



LselNoEssential = 77



MdhdBadTimescale = 78



MdhdBadVersion = 79



MehdBadVersion = 80



MetaBadQuantity = 81



MissingAvifOrAvisBrand = 82



MissingMif1Brand = 83



MoovBadQuantity = 84



MoovMissing = 85



MultipleAlpha = 86



MvhdBadTimescale = 87



MvhdBadVersion = 88



NoImage = 89



PitmBadQuantity = 90



PitmMissing = 91



PitmNotFound = 92



PixiBadChannelCount = 93



PixiMissing = 94



PsshSizeOverflow = 95



ReadBufErr = 96



SchiQuantity = 97



StsdBadAudioSampleEntry = 98



StsdBadVideoSampleEntry = 99



TkhdBadVersion = 100



TxformBeforeIspe = 101



TxformNoEssential = 102



TxformOrder = 103